/* ThemeRoller SwankyPurse override style sheet for jQuery Calendars Picker v2.0.0. */
@import "ui.calendars.picker.css";

.ui-widget-header a,
.ui-widget-header select {
	color: #eacd86; /* Set (.ui-widget-header a) colour from theme here */
}
.ui-widget-header a:hover {
	background-color: #675423; /* Set (.ui-state-hover) colours from theme here */
	color: #f8eec9;
}
.ui-widget-header select,
.ui-widget-header option {
	background-color: #261803; /* Set (.ui-widget-header) background colour from theme here */
}
.ui-state-highlight a {
	color: #060200; /* Set (.ui-state-highlight) colour from theme here */
}
